@@ -32,13 +32,17 @@
  *
  */
 
-#include "mlview-app.h"
 #include <stdio.h>
 #include <locale.h>
 #include <gnome.h>
 #include <libxml/parser.h>
 #include <libxml/catalog.h>
 
+#include "mlview-app.h"
+#include "mlview-service.h"
+
+/*#include "mlview-dbus-manager.h"*/
+
 
 /**
  *MlView main entry point.
@@ -84,6 +88,7 @@ main (int argc, char **argv)
                  NULL},
                 {0}
         };
+
         /*init underlaying facilities */
         mlview_utils_init ();
 
@@ -125,6 +130,17 @@ main (int argc, char **argv)
         /*instanciate an mlview application */
         mlview_application = mlview_app_new ((guchar*)PACKAGE);
 
+	/* Bootstrap facilities */
+	mlview_service_start (mlview_application, NULL) ;
+        /*mlview_dbus_manager_init (mlview_application, args);*/
+        /* !!! WARNING !!!
+         * if there is already an instance of mlview running
+         * program will exit in mlview_dbus_manager_init
+         */
+
+        /* Make window visible now */
+        mlview_app_set_visible (mlview_application);
+
         if (args) {
                 /*
                  *they are some argument on the comment line. Treat them 
@@ -141,7 +157,8 @@ main (int argc, char **argv)
                                 mlview_editor_load_xml_file_with_dtd
                                         (mlview_editor,
                                          (gchar *) args[i],
-                                         associated_dtd);
+                                         associated_dtd,
+					 TRUE);
                         }
                 }
         }
