@@ -55,6 +55,11 @@
 #define DEFAULT_EDITING_VIEW_TYPE_KEY "/apps/mlview/default-editing-view-type"
 #define ENABLE_COMPLETION_BOX_KEY "/apps/mlview/enable-completion-box"
 
+#define MAIN_WINDOW_WIDTH_KEY "/apps/mlview/sizes/main-window-width"
+#define MAIN_WINDOW_HEIGHT_KEY "/apps/mlview/sizes/main-window-height"
+#define TREE_EDITOR_SIZE_KEY "/apps/mlview/sizes/tree-editor-size"
+#define COMPLETION_SIZE_KEY "/apps/mlview/sizes/completion-size"
+
 static const gchar *tree_editors_node_colours_keys[NB_OF_TREE_NODE_COLOURS + 1] = 
 {"/apps/mlview/colours/xml-element-node",
  "/apps/mlview/colours/xml-attribute-node",
@@ -83,7 +88,7 @@ enum NumberOfSignals {
         CONTEXTUAL_MENU_REQUESTED,
         VIEW_SWAPPED,
         DOCUMENT_NAME_CHANGED,
-        DOCUMENT_UNDO_STATE_CHANGED,
+        VIEW_UNDO_STATE_CHANGED,
         NUMBER_OF_SIGNALS
 } ;
 
@@ -302,15 +307,15 @@ mlview_app_context_class_init (MlViewAppContextClass * a_klass)
                               mlview_marshal_VOID__POINTER,
                               G_TYPE_NONE, 1, G_TYPE_POINTER);
 
-        gv_signals[DOCUMENT_UNDO_STATE_CHANGED] =
-                g_signal_new ("document-undo-state-changed",
+        gv_signals[VIEW_UNDO_STATE_CHANGED] =
+                g_signal_new ("view-undo-state-changed",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET
                               (MlViewAppContextClass,
-                               document_undo_state_changed), NULL, NULL,
-                              mlview_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                               view_undo_state_changed), NULL, NULL,
+                              mlview_marshal_VOID__VOID,
+                              G_TYPE_NONE, 0, NULL);
 }
 
 
@@ -742,18 +747,14 @@ mlview_app_context_notify_document_name_changed (MlViewAppContext *a_this,
 
 
 enum MlViewStatus 
-mlview_app_context_notify_document_undo_state_changed (MlViewAppContext *a_this,
-                                                       gpointer  a_doc)
+mlview_app_context_notify_view_undo_state_changed (MlViewAppContext *a_this)
 {
         g_return_val_if_fail (a_this && MLVIEW_IS_APP_CONTEXT (a_this)
-                              && PRIVATE (a_this),
+                              && PRIVATE (a_this) ,
                               MLVIEW_BAD_PARAM_ERROR) ;
 
-        if (a_doc) {
-                g_signal_emit (G_OBJECT (a_this),
-                               gv_signals[DOCUMENT_UNDO_STATE_CHANGED], 0,
-                               a_doc) ;
-        }
+	g_signal_emit (G_OBJECT (a_this),
+		       gv_signals[VIEW_UNDO_STATE_CHANGED], 0) ;
         return MLVIEW_OK ;
 }
 
@@ -1189,7 +1190,26 @@ mlview_app_context_gconf_notify_func (GConfClient *a_gconf_client,
         } else if (!strcmp (key, DEFAULT_EDITING_VIEW_TYPE_KEY)) {
                 settings->general.default_editing_view_type =
                         eel_gconf_get_string (key) ;
-        }
+        } else if (!strcmp (key, MAIN_WINDOW_WIDTH_KEY)) {
+		value = gconf_entry_get_value (a_entry);
+		settings->sizes.main_window_width =
+			gconf_value_get_int (value);
+	} else if (!strcmp (key, MAIN_WINDOW_HEIGHT_KEY)) {
+		value = gconf_entry_get_value (a_entry);
+		settings->sizes.main_window_height =
+			gconf_value_get_int (value);
+	} else if (!strcmp (key, TREE_EDITOR_SIZE_KEY)) {
+		value = gconf_entry_get_value (a_entry);
+		settings->sizes.tree_editor_size =
+			gconf_value_get_int (value);
+	} else if (!strcmp (key, COMPLETION_SIZE_KEY)) {
+		value = gconf_entry_get_value (a_entry);
+		settings->sizes.completion_size =
+			gconf_value_get_int (value);
+	}
+
+
+
 }
 
 /**
@@ -1229,6 +1249,14 @@ mlview_app_context_load_gconf_settings (MlViewAppContext *a_this)
                 eel_gconf_get_boolean (ENABLE_COMPLETION_BOX_KEY);
         settings->general.default_editing_view_type =
                 eel_gconf_get_string (DEFAULT_EDITING_VIEW_TYPE_KEY) ;
+	settings->sizes.main_window_width =
+		eel_gconf_get_integer (MAIN_WINDOW_WIDTH_KEY);
+	settings->sizes.main_window_height =
+		eel_gconf_get_integer (MAIN_WINDOW_HEIGHT_KEY);
+	settings->sizes.tree_editor_size =
+		eel_gconf_get_integer (TREE_EDITOR_SIZE_KEY);
+	settings->sizes.completion_size =
+		eel_gconf_get_integer (COMPLETION_SIZE_KEY);
         for (i = 0 ;
              i < NB_OF_TREE_NODE_COLOURS && tree_editors_node_colours_keys[i];
              i++) {
@@ -1296,7 +1324,7 @@ mlview_app_context_get_settings (MlViewAppContext *a_this)
                         g_try_malloc
                         (sizeof (struct MlViewAppSettings)) ;
                 if (!PRIVATE (a_this)->settings) {
-                        mlview_utils_trace_info
+                        mlview_utils_trace_debug
                                 ("g_try_malloc () failed") ;
                         return NULL ;
                 }
@@ -1307,7 +1335,55 @@ mlview_app_context_get_settings (MlViewAppContext *a_this)
         return PRIVATE (a_this)->settings ;
 }
 
+/**
+ * Save main window size settings
+ */
+void
+mlview_app_context_save_window_state (MlViewAppContext *a_this, gint width, gint height)
+{
+	 g_return_if_fail (a_this 
+                              && MLVIEW_IS_APP_CONTEXT (a_this)
+                              && PRIVATE (a_this));
+	
+	gconf_client_set_int (
+			PRIVATE (a_this)->gconf_client,
+			MAIN_WINDOW_WIDTH_KEY,
+			width,
+			NULL);
 
+	gconf_client_set_int (
+			PRIVATE (a_this)->gconf_client,
+			MAIN_WINDOW_HEIGHT_KEY,
+			height,
+			NULL);
+}
+
+/**
+ * Save TreeView paned positions state
+ */
+void
+mlview_app_context_save_treeview_state (
+				MlViewAppContext *a_this,
+				gint treeview_height,
+				gint completion_box_size)
+{
+	g_return_if_fail (a_this 
+                              && MLVIEW_IS_APP_CONTEXT (a_this)
+                              && PRIVATE (a_this));
+	
+	gconf_client_set_int (
+			PRIVATE (a_this)->gconf_client,
+			TREE_EDITOR_SIZE_KEY,
+			treeview_height,
+			NULL);
+
+	gconf_client_set_int (
+			PRIVATE (a_this)->gconf_client,
+			COMPLETION_SIZE_KEY,
+			completion_box_size,
+			NULL);
+}
+	
 /**
  *Gets the file selection dialog box associated to the mlview application.
  *The first call to this method creates the file selection. Subsequent
@@ -1346,43 +1422,49 @@ mlview_app_context_get_file_selector (MlViewAppContext *a_this,
 #ifdef MLVIEW_WITH_GTK_FILE_CHOOSER
 GtkFileChooser *
 mlview_app_context_get_file_chooser (MlViewAppContext *a_this,
-                                     const gchar *a_title)
+                                     const gchar *a_title, MlViewFileChooserMode a_mode)
 {
         g_return_val_if_fail (a_this 
                               && MLVIEW_IS_APP_CONTEXT (a_this)
                               && PRIVATE (a_this),
                               NULL) ;
 
-        if (!PRIVATE (a_this)->file_chooser) {
-                GtkWidget * parent_window = NULL ;
-                parent_window = mlview_app_context_get_element (a_this,
-                                                                "MlViewMainWindow") ;
-                PRIVATE (a_this)->file_chooser = GTK_FILE_CHOOSER (gtk_file_chooser_dialog_new
-                                                                   (a_title,
-                                                                    GTK_WINDOW (parent_window),
-                                                                    GTK_FILE_CHOOSER_ACTION_SAVE, 
-                                                                    GTK_STOCK_CANCEL, 
-                                                                    GTK_RESPONSE_CANCEL, 
-                                                                    GTK_STOCK_OPEN,
-                                                                    GTK_RESPONSE_OK,
-                                                                    NULL));
-                g_return_val_if_fail (PRIVATE (a_this)->file_chooser != NULL, NULL) ;
-                g_signal_connect (G_OBJECT (PRIVATE (a_this)->file_chooser),
-                                  "delete-event",
-                                  G_CALLBACK (gtk_widget_hide_on_delete),
-                                  NULL) ;
-                gtk_window_set_modal (GTK_WINDOW (PRIVATE (a_this)->file_chooser),
-                                      TRUE) ;
-                gtk_file_chooser_set_local_only 
-                        (PRIVATE (a_this)->file_chooser, TRUE);
-                gtk_file_chooser_set_select_multiple 
-                        (GTK_FILE_CHOOSER (PRIVATE (a_this)->file_chooser),
-                         FALSE);
-        }
+        /*if (!PRIVATE (a_this)->file_chooser) {*/
+	GtkWidget * parent_window = NULL ;
+
+	parent_window = mlview_app_context_get_element (a_this,
+							"MlViewMainWindow") ;
+
+	PRIVATE (a_this)->file_chooser = GTK_FILE_CHOOSER (gtk_file_chooser_dialog_new
+							   (a_title,
+							    GTK_WINDOW (parent_window),
+							    GTK_FILE_CHOOSER_ACTION_OPEN, 
+							    GTK_STOCK_CANCEL, 
+							    GTK_RESPONSE_CANCEL, 
+							    (a_mode == MlViewFileChooserOpenMode) ? GTK_STOCK_OPEN : GTK_STOCK_SAVE,
+							    GTK_RESPONSE_OK,
+							    NULL));
+	g_return_val_if_fail (PRIVATE (a_this)->file_chooser != NULL, NULL) ;
+	g_signal_connect (G_OBJECT (PRIVATE (a_this)->file_chooser),
+			  "delete-event",
+			  G_CALLBACK (gtk_widget_hide_on_delete),
+			  NULL) ;
+	gtk_window_set_modal (GTK_WINDOW (PRIVATE (a_this)->file_chooser),
+			      TRUE) ;
+	gtk_file_chooser_set_local_only 
+		(PRIVATE (a_this)->file_chooser, TRUE);
+	gtk_file_chooser_set_select_multiple 
+		(GTK_FILE_CHOOSER (PRIVATE (a_this)->file_chooser),
+		 FALSE);
+        /*}*/
         g_return_val_if_fail (PRIVATE (a_this)->file_chooser != NULL, NULL) ;
         gtk_window_set_title (GTK_WINDOW (PRIVATE (a_this)->file_chooser),
                               a_title) ;
-        
+	if (a_mode == MlViewFileChooserOpenMode)
+		gtk_file_chooser_set_action (PRIVATE (a_this)->file_chooser, GTK_FILE_CHOOSER_ACTION_OPEN);
+	else
+		gtk_file_chooser_set_action (PRIVATE (a_this)->file_chooser, GTK_FILE_CHOOSER_ACTION_SAVE);
+
         return PRIVATE (a_this)->file_chooser ;
 }
 #endif
@@ -1479,7 +1561,7 @@ mlview_app_context_load_type_icons (MlViewAppContext *a_this)
         type_icons = g_try_malloc (sizeof (struct MlViewTypeIcons));
 
         if (!type_icons) {
-                mlview_utils_trace_info ("malloc failed, system may be out of memory");
+                mlview_utils_trace_debug ("malloc failed, system may be out of memory");
 
                 return NULL;
         }
@@ -1488,8 +1570,8 @@ mlview_app_context_load_type_icons (MlViewAppContext *a_this)
                                           ELEMENT_ICON, TRUE, NULL);
 
         if (!path) {
-                mlview_utils_trace_info ("lookup of icon file failed:") ;
-                mlview_utils_trace_info (ELEMENT_ICON) ;
+                mlview_utils_trace_debug ("lookup of icon file failed:") ;
+                mlview_utils_trace_debug (ELEMENT_ICON) ;
         } else {
                 type_icons->element = gdk_pixbuf_new_from_file (path, NULL);
                 g_free (path);
@@ -1498,8 +1580,8 @@ mlview_app_context_load_type_icons (MlViewAppContext *a_this)
         path = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
                                           OPEN_ELEMENT_ICON, TRUE, NULL);
         if (!path) {
-                mlview_utils_trace_info ("lookup of icon file failed:") ;
-                mlview_utils_trace_info (OPEN_ELEMENT_ICON) ;
+                mlview_utils_trace_debug ("lookup of icon file failed:") ;
+                mlview_utils_trace_debug (OPEN_ELEMENT_ICON) ;
         } else {
                 type_icons->open_element = gdk_pixbuf_new_from_file (path, NULL);
                 g_free (path);
@@ -1508,8 +1590,8 @@ mlview_app_context_load_type_icons (MlViewAppContext *a_this)
         path = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
                                           TEXT_ICON, TRUE, NULL);
         if (!path) {
-                mlview_utils_trace_info ("lookup of icon file failed:") ;
-                mlview_utils_trace_info (TEXT_ICON) ;
+                mlview_utils_trace_debug ("lookup of icon file failed:") ;
+                mlview_utils_trace_debug (TEXT_ICON) ;
         } else {
                 type_icons->text = gdk_pixbuf_new_from_file (path, NULL);
                 g_free (path);
@@ -1518,8 +1600,8 @@ mlview_app_context_load_type_icons (MlViewAppContext *a_this)
         path = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
                                           ROOT_ICON, TRUE, NULL);
         if (!path) {
-                mlview_utils_trace_info ("lookup of icon file failed:") ;
-                mlview_utils_trace_info (ROOT_ICON) ;
+                mlview_utils_trace_debug ("lookup of icon file failed:") ;
+                mlview_utils_trace_debug (ROOT_ICON) ;
         } else {
                 type_icons->root = gdk_pixbuf_new_from_file (path, NULL);
                 g_free (path);
@@ -1528,8 +1610,8 @@ mlview_app_context_load_type_icons (MlViewAppContext *a_this)
         path = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
                                           OPEN_ROOT_ICON, TRUE, NULL) ;
         if (!path) {
-                mlview_utils_trace_info ("lookup of icon file failed:") ;
-                mlview_utils_trace_info (OPEN_ROOT_ICON) ;
+                mlview_utils_trace_debug ("lookup of icon file failed:") ;
+                mlview_utils_trace_debug (OPEN_ROOT_ICON) ;
         } else {
                 type_icons->open_root = gdk_pixbuf_new_from_file (path, NULL);
                 g_free (path);
@@ -1538,8 +1620,8 @@ mlview_app_context_load_type_icons (MlViewAppContext *a_this)
         path = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
                                           COMMENT_ICON, TRUE, NULL);
         if (!path) {
-                mlview_utils_trace_info ("lookup of icon file failed:") ;
-                mlview_utils_trace_info (COMMENT_ICON) ;
+                mlview_utils_trace_debug ("lookup of icon file failed:") ;
+                mlview_utils_trace_debug (COMMENT_ICON) ;
         } else {
                 type_icons->comment = gdk_pixbuf_new_from_file (path, NULL);
                 g_free (path);
@@ -1548,8 +1630,8 @@ mlview_app_context_load_type_icons (MlViewAppContext *a_this)
         path = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
                                           ENTITY_REF_ICON, TRUE, NULL);
         if (!path) {
-                mlview_utils_trace_info ("lookup of icon file failed:") ;
-                mlview_utils_trace_info (ENTITY_REF_ICON) ;
+                mlview_utils_trace_debug ("lookup of icon file failed:") ;
+                mlview_utils_trace_debug (ENTITY_REF_ICON) ;
         } else {
                 type_icons->entity_ref = gdk_pixbuf_new_from_file (path, NULL);
                 g_free (path);
@@ -1558,8 +1640,8 @@ mlview_app_context_load_type_icons (MlViewAppContext *a_this)
         path = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
                                           PI_ICON, TRUE, NULL);
         if (!path) {
-                mlview_utils_trace_info ("lookup of icon file failed:") ;
-                mlview_utils_trace_info (PI_ICON) ;
+                mlview_utils_trace_debug ("lookup of icon file failed:") ;
+                mlview_utils_trace_debug (PI_ICON) ;
         } else {
                 type_icons->pi = gdk_pixbuf_new_from_file (path, NULL);
                 g_free (path);
