@@ -212,7 +212,7 @@ mlview_attrs_editor_init (MlViewAttrsEditor * a_this)
         PRIVATE (a_this) =
                 g_try_malloc (sizeof (MlViewAttrsEditorPrivate));
         if (!PRIVATE (a_this)) {
-                mlview_utils_trace_info ("g_try_malloc failed") ;
+                mlview_utils_trace_debug ("g_try_malloc failed") ;
                 return ;
         }
         memset (PRIVATE (a_this), 0, 
@@ -276,6 +276,11 @@ mlview_attrs_editor_construct (MlViewAttrsEditor *a_this,
                           G_CALLBACK (row_selected_cb),
                           a_this);
         scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_policy (
+			GTK_SCROLLED_WINDOW (scrolled_window),
+			GTK_POLICY_AUTOMATIC,
+			GTK_POLICY_AUTOMATIC);
+
         gtk_container_add
                 (GTK_CONTAINER (scrolled_window),
                  GTK_WIDGET (PRIVATE (a_this)->attrs_view));
@@ -399,7 +404,7 @@ mlview_attrs_editor_add_attribute_to_node_interactive (MlViewAttrsEditor * a_thi
                 mlview_xml_document_get_node_path  (PRIVATE (a_this)->mlview_xml_doc, 
                                                     a_node, &node_path) ;
                 if (!node_path) {
-                        mlview_utils_trace_info ("Could not get node xpath expr") ;
+                        mlview_utils_trace_debug ("Could not get node xpath expr") ;
                         return MLVIEW_ERROR ;
                 }
         }
@@ -555,7 +560,7 @@ associate_row_ref_to_xml_attr (MlViewAttrsEditor *a_this,
                         g_hash_table_new
                         (g_direct_hash, g_direct_equal) ;
                 if (!PRIVATE (a_this)->attr_row_hash) {
-                        mlview_utils_trace_info ("g_hash_table_new() "
+                        mlview_utils_trace_debug ("g_hash_table_new() "
                                                  "failed.") ;
                         return MLVIEW_OUT_OF_MEMORY_ERROR ;
                 }
@@ -690,7 +695,7 @@ get_cur_selected_iter (MlViewAttrsEditor *a_this,
         g_return_val_if_fail (tree_path, MLVIEW_ERROR) ;
         model = mlview_attrs_editor_get_model (a_this) ;
         if (!model) {
-                mlview_utils_trace_info ("model failed") ;
+                mlview_utils_trace_debug ("model failed") ;
                 goto cleanup ;
         }
         gtk_tree_model_get_iter (model, a_iter, tree_path) ;
@@ -783,7 +788,7 @@ attr_name_cell_edited_cb (GtkCellRendererText *a_renderer,
                                            PRIVATE (a_editor)->current_xml_node,
                                            &node_path) ;
         if (!node_path) {
-                mlview_utils_trace_info ("Could not get XPATH expr from XML node") ;
+                mlview_utils_trace_debug ("Could not get XPATH expr from XML node") ;
                 return ;
         }
 
@@ -876,7 +881,7 @@ attr_value_cell_edited_cb (GtkCellRendererText *a_renderer,
                                            PRIVATE (a_editor)->current_xml_node,
                                            &node_path) ;
         if (!node_path) {
-                mlview_utils_trace_info ("Could not get XPATH expr from node") ;
+                mlview_utils_trace_debug ("Could not get XPATH expr from node") ;
                 return ;
         }
         model = mlview_attrs_editor_get_model (a_editor) ;
@@ -1076,7 +1081,7 @@ mlview_attrs_editor_get_new_row_ref (MlViewAttrsEditor *a_this,
         g_return_val_if_fail (tree_path, NULL) ;
         ref = gtk_tree_row_reference_new (model, tree_path) ;
         if (!ref) {
-                mlview_utils_trace_info ("result failed") ;
+                mlview_utils_trace_debug ("result failed") ;
                 goto cleanup ;
         }
         xml_attr = mlview_attrs_editor_get_xml_attr (a_this, a_iter) ;
@@ -1087,13 +1092,13 @@ mlview_attrs_editor_get_new_row_ref (MlViewAttrsEditor *a_this,
                                     &is_add_new_attr_row,
                                     -1) ;
                 if (is_add_new_attr_row == FALSE) {
-                        mlview_utils_trace_info ("xml_attr failed") ;
+                        mlview_utils_trace_debug ("xml_attr failed") ;
                         goto cleanup ;
                 }
         }
         status = associate_row_ref_to_xml_attr (a_this, ref, xml_attr) ;
         if (status != MLVIEW_OK) {
-                mlview_utils_trace_info ("status == MLVIEW_OK failed") ;
+                mlview_utils_trace_debug ("status == MLVIEW_OK failed") ;
                 goto cleanup ;
         }
         result = ref ;
@@ -1234,7 +1239,7 @@ mlview_attrs_editor_get_cur_sel_iter (MlViewAttrsEditor *a_this,
         g_return_val_if_fail (tree_path, MLVIEW_ERROR) ;        
         is_ok = gtk_tree_model_get_iter (model, a_iter, tree_path) ;
         if (is_ok != TRUE) {
-                mlview_utils_trace_info ("is_ok == TRUE failed") ;
+                mlview_utils_trace_debug ("is_ok == TRUE failed") ;
                 status = MLVIEW_ERROR ;
                 goto cleanup ;
         }
@@ -1389,7 +1394,7 @@ mlview_attrs_editor_insert_attribute (MlViewAttrsEditor *a_this,
         row_ref = mlview_attrs_editor_get_new_row_ref 
                 (a_this, a_iter) ;
         if (!row_ref) {
-                mlview_utils_trace_info 
+                mlview_utils_trace_debug 
                         ("mlview_attrs_editor_get_new_row_ref () failed") ;
                 status = MLVIEW_ERROR ;
                 goto cleanup ;                
@@ -1718,13 +1723,13 @@ mlview_attrs_editor_update_attribute (MlViewAttrsEditor *a_this,
                         (row_ref) ;
                 if (!tree_path) {
                         status = MLVIEW_ERROR ;
-                        mlview_utils_trace_info ("tree_path failed") ;
+                        mlview_utils_trace_debug ("tree_path failed") ;
                         goto cleanup ;
                 }
                 model = mlview_attrs_editor_get_model (a_this) ;
                 if (!model) {
                         status = MLVIEW_ERROR ;
-                        mlview_utils_trace_info 
+                        mlview_utils_trace_debug 
                                 ("mlview_attrs_editor_get_model () failed") ;
                         goto cleanup ;
                 }
@@ -1790,14 +1795,14 @@ mlview_attrs_editor_update_attribute_removed (MlViewAttrsEditor *a_this,
                         (row_ref) ;
                 model = mlview_attrs_editor_get_model (a_this) ;
                 if (!model) {
-                        mlview_utils_trace_info 
+                        mlview_utils_trace_debug 
                                 ("mlview_attrs_editor_get_model () failed") ;
                         goto cleanup ;
                 }
                 is_ok = gtk_tree_model_get_iter 
                         (model, &iter, tree_path) ;
                 if (is_ok == FALSE) {
-                        mlview_utils_trace_info ("gtk_tree_model_get_iter() failed") ;
+                        mlview_utils_trace_debug ("gtk_tree_model_get_iter() failed") ;
                         goto cleanup ;
                 }
         }
