@@ -34,7 +34,10 @@
 
 G_BEGIN_DECLS
 #include <libxml/tree.h>
+#include <libxml/relaxng.h>
+#include <libxml/xmlschemas.h>
 #include "mlview-app-context.h"
+#include "mlview-xml-document.h"
 
 enum NODE_INSERTION_SCHEME {
         /*Insert node before current selected node */
@@ -44,7 +47,10 @@ enum NODE_INSERTION_SCHEME {
         INSERT_AFTER,
 
         /*add a child node */
-        ADD_CHILD
+        ADD_CHILD,
+        
+        /*Change the name of the current element node*/
+        CHANGE_CUR_ELEMENT_NAME
 };
 
 enum MLVIEW_PARSING_UTILS_STATUS {
@@ -83,8 +89,13 @@ void mlview_ext_subs_def_destroy (MlViewExtSubsDef * a_def);
 
 MlViewExtSubsDef * mlview_utils_get_a_copy_of_last_ext_subs_def (void);
 
-xmlDoc *mlview_parsing_utils_load_xml_file (gchar * a_file_name,
-                                            MlViewAppContext * a_app_context) ;
+xmlDocPtr mlview_parsing_utils_load_xml_file_with_dtd_interactive 
+						(const gchar * a_file_name, 
+						 MlViewAppContext * a_app_context) ;
+
+xmlDocPtr mlview_parsing_utils_load_xml_file_with_dtd (const gchar *a_file_name,
+                                                       const gchar *a_dtd_name,
+                                                       MlViewAppContext *a_app_context);
 
 xmlDtd *mlview_parsing_utils_load_a_dtd (MlViewExtSubsDef * a_subset_def,
                                          MlViewAppContext * a_app_context) ;
@@ -93,11 +104,9 @@ gint mlview_parsing_utils_validate_dtd (xmlDoc * a_doc,
                                         xmlDtd * a_dtd,
                                         MlViewAppContext * a_app_context);
 
-gint mlview_parsing_utils_save_xml_doc (xmlDoc * a_xml_doc, gchar * a_file_path,
-                                        MlViewAppContext * a_app_context) ;
 
 MlViewExtSubsDef * mlview_parsing_utils_let_user_choose_a_dtd (MlViewAppContext * a_app_ctxt, 
-                                                                             gchar * a_title) ;
+                                                               gchar * a_title) ;
 
 gint mlview_parsing_utils_build_element_name_completion_list (MlViewAppContext * a_app_context,
                                                               enum NODE_INSERTION_SCHEME a_insertion_scheme,
@@ -127,5 +136,32 @@ GList *mlview_parsing_utils_build_graphical_attr_values (MlViewAppContext * a_ap
                                                          xmlAttribute * a_attribute_desc, 
                                                          gint * a_last_id);
 
+xmlDtdPtr mlview_parsing_utils_load_dtd (const gchar *a_url,
+                                         MlViewAppContext *a_ctxt);
+
+xmlRelaxNGPtr mlview_parsing_utils_load_rng (const gchar *a_url,
+                                             MlViewAppContext *a_ctxt);
+
+xmlSchemaPtr mlview_parsing_utils_load_xsd (const gchar *a_url,
+                                            MlViewAppContext *a_ctxt);
+
+void mlview_parsing_utils_clean_dtd (xmlDtdPtr a_dtd);
+
+enum MlViewStatus mlview_parsing_utils_parse_fragment (xmlDoc *a_doc,
+                                                       const xmlChar *a_buf,
+                                                       xmlNode **a_result_node) ;
+
+enum MlViewStatus mlview_parsing_utils_serialize_node_to_buf (const xmlNode *a_node,
+                                                              gchar **out_buf) ;
+
+enum MlViewStatus mlview_parsing_utils_do_comment_node (const xmlNode *a_node,
+                                                        xmlNode **a_comment_node) ;
+
+
+enum MlViewStatus
+mlview_parsing_utils_uncomment_node (xmlDoc *a_doc,
+		                     const xmlNode *comment_node,
+		                     xmlNode **a_result_node) ;
 G_END_DECLS
+
 #endif
