@@ -29,11 +29,24 @@
 #include "mlview-parsing-utils.h"
 #include "mlview-utils.h"
 
+#define PRIVATE(object) ((object)->priv)
+
 struct _MlViewSchemaPrivate {
+	/*the url of the schema*/
         gchar *url;
+
+	/*The refcount of the schema*/
         guint ref;
+
+	/*the type of the underlying native schema (rng, xsd or dtd)*/
         enum MlViewSchemaType type;
 
+	/* whether to free the native underlying schema upon destruction
+	 * of the MlViewSchema
+	 */
+	gboolean free_native_schema ;
+
+	/*the storage of the native schema*/
         union {
                 xmlDtdPtr dtd;
                 xmlRelaxNGPtr rng;
@@ -44,7 +57,8 @@ struct _MlViewSchemaPrivate {
 MlViewSchema *
 mlview_schema_new_from_dtd (xmlDtdPtr a_dtd,
                             const gchar *a_url,
-                            MlViewAppContext *a_ctxt)
+                            MlViewAppContext *a_ctxt,
+			    gboolean a_free_dtd_on_destroy)
 {
         MlViewSchema *schema = NULL;
 
@@ -74,6 +88,8 @@ mlview_schema_new_from_dtd (xmlDtdPtr a_dtd,
         schema->priv->type = SCHEMA_TYPE_DTD;
 
         schema->priv->schema.dtd = a_dtd;
+	schema->priv->free_native_schema = 
+		a_free_dtd_on_destroy ;
 
         mlview_schema_ref (schema);
 
@@ -163,6 +179,7 @@ mlview_schema_load_from_file (const gchar *a_url,
                 break ;
         }
 
+	schema->priv->free_native_schema = TRUE ;
         mlview_schema_ref (schema);
 
         return schema;
@@ -187,59 +204,80 @@ mlview_schema_load_from_file (const gchar *a_url,
 }
 
 void
-mlview_schema_ref (MlViewSchema *a_schema)
+mlview_schema_ref (MlViewSchema *a_this)
 {
-        g_return_if_fail (a_schema && a_schema->priv);
+        g_return_if_fail (a_this && PRIVATE (a_this));
 
-        a_schema->priv->ref++;
+        PRIVATE (a_this)->ref++;
 }
 
 void
-mlview_schema_unref (MlViewSchema *a_schema)
+mlview_schema_unref (MlViewSchema *a_this)
 {
-        g_return_if_fail (a_schema && a_schema->priv);
+        g_return_if_fail (a_this && PRIVATE (a_this));
 
-        a_schema->priv->ref--;
+        PRIVATE (a_this)->ref--;
+	if (PRIVATE (a_this)->ref)
+		return ;
+	if (PRIVATE (a_this)->free_native_schema == TRUE) {
+		mlview_schema_destroy (a_this, FALSE) ;
+	} else {
+		mlview_schema_destroy (a_this, TRUE) ;
+	}
+}
 
-        if (!a_schema->priv->ref) {
-                switch (a_schema->priv->type) {
-                case SCHEMA_TYPE_DTD:
-                        if (a_schema->priv->schema.dtd) {
-                                xmlFreeDtd (a_schema->priv->schema.dtd);
-                                a_schema->priv->schema.dtd = NULL;
-                        }
-                        break;
-                case SCHEMA_TYPE_RNG:
-                        if (a_schema->priv->schema.rng) {
-                                xmlRelaxNGFree (a_schema->priv->schema.rng);
-                                a_schema->priv->schema.rng = NULL;
-                        }
-                        break;
-                case SCHEMA_TYPE_XSD:
-                        if (a_schema->priv->schema.xsd) {
-                                xmlSchemaFree (a_schema->priv->schema.xsd);
-                                a_schema->priv->schema.xsd = NULL;
-                        }
-                        break;
+void 
+mlview_schema_destroy (MlViewSchema *a_this,
+		       gboolean a_free_native_schema)
+{
+	g_return_if_fail (a_this && PRIVATE (a_this)) ;
 
-                default:
-                        g_assert_not_reached () ;
-                        break ;
-                }
 
-                if (a_schema->priv) {
-                        if (a_schema->priv->url) {
-                                g_free (a_schema->priv->url);
-                                a_schema->priv->url = NULL;
-                        }
-                        
-                        g_free (a_schema->priv);
-                        a_schema->priv = NULL;
-                }
+	switch (PRIVATE (a_this)->type) {
+	case SCHEMA_TYPE_DTD:
+		if (a_free_native_schema == TRUE
+		    && PRIVATE (a_this)->schema.dtd) {
+			if (PRIVATE (a_this)->free_native_schema) {
+				xmlFreeDtd (PRIVATE (a_this)->schema.dtd);
+			}	
+			PRIVATE (a_this)->schema.dtd = NULL;
+		}
+		break;
+	case SCHEMA_TYPE_RNG:
+		if (a_free_native_schema == TRUE
+		    && PRIVATE (a_this)->schema.rng) {
+			if (PRIVATE (a_this)->free_native_schema) {
+				xmlRelaxNGFree (PRIVATE (a_this)->schema.rng);
+			}
+			PRIVATE (a_this)->schema.rng = NULL;
+		}
+		break;
+	case SCHEMA_TYPE_XSD:
+		if (a_free_native_schema == TRUE 
+		    && PRIVATE (a_this)->schema.xsd) {
+			if (PRIVATE (a_this)->free_native_schema) {
+				xmlSchemaFree (PRIVATE (a_this)->schema.xsd);
+			}
+			PRIVATE (a_this)->schema.xsd = NULL;
+		}
+		break;
 
-                g_free (a_schema);
-                a_schema = NULL;
-        }
+	default:
+		g_assert_not_reached () ;
+		break ;
+	}
+
+	if (PRIVATE (a_this)) {
+		if (PRIVATE (a_this)->url) {
+			g_free (PRIVATE (a_this)->url);
+			PRIVATE (a_this)->url = NULL;
+		}
+		
+		g_free (PRIVATE (a_this));
+		PRIVATE (a_this) = NULL;
+	}
+	g_free (a_this);
+	a_this = NULL;
 }
 
 gchar *
