@@ -139,7 +139,7 @@ mlview_styled_view_init (MlViewStyledView *a_this)
 		PRIVATE (a_this) = g_try_malloc 
 			(sizeof (MlViewStyledViewPriv)) ;
 		if (!PRIVATE (a_this)) {
-			mlview_utils_trace_info ("g_try_malloc failed") ;
+			mlview_utils_trace_debug ("g_try_malloc failed") ;
 			return ;
 		}
 		memset (PRIVATE (a_this), 0, 
@@ -338,7 +338,7 @@ contextual_menu_request_cb (MlViewAppContext *a_this,
                                         a_this, button_event->button,
                                         button_event->time) ;
                 } else {
-                        mlview_utils_trace_info ("Null menu returned") ;
+                        mlview_utils_trace_debug ("Null menu returned") ;
                 }
         }
 }
@@ -373,7 +373,7 @@ dump_box_model_menuitem_clicked_cb (GtkMenuItem *a_item,
         if (status == CR_OK && box_model) {
                 sx_box_dump_to_file ((SXBox*)box_model, 2, stdout) ;
         } else {
-                mlview_utils_trace_info ("Could not get box model") ;
+                mlview_utils_trace_debug ("Could not get box model") ;
         }
         
 }
@@ -548,20 +548,20 @@ get_css_paths_picker_dialog (MlViewStyledView *a_this)
                                                   "mlview/mlview-css-picker.glade",
                                                   TRUE, NULL) ;
                 if (!path) {
-                        mlview_utils_trace_info
+                        mlview_utils_trace_debug
                                 ("could not find mlview-css-picker.glade file") ;
                         return NULL ;
                 }
                 glade_xml = glade_xml_new (path, "CSSPicker", NULL) ;
                 if (!glade_xml) {
-                        mlview_utils_trace_info ("could not find mlview-css-picker.glade file") ;
+                        mlview_utils_trace_debug ("could not find mlview-css-picker.glade file") ;
                         goto cleanup ;
                 }
                 PRIVATE (a_this)->css_picker_dialog = GTK_DIALOG 
                         (glade_xml_get_widget (glade_xml, "CSSPicker")) ;
                 if (!PRIVATE (a_this)->css_picker_dialog 
                     || !GTK_IS_DIALOG (PRIVATE (a_this)->css_picker_dialog)) {
-                        mlview_utils_trace_info ("glade_xml_get_widget() made an unexpected result") ;
+                        mlview_utils_trace_debug ("glade_xml_get_widget() made an unexpected result") ;
                 }
                 PRIVATE (a_this)->css_picker_author_css_path =
                         GTK_ENTRY (glade_xml_get_widget (glade_xml, 
@@ -838,7 +838,7 @@ mlview_styled_view_get_type (void)
  */
 GtkWidget*
 mlview_styled_view_new (MlViewXMLDocument *a_doc,
-                        gchar *a_name,
+                        const gchar *a_name,
                         MlViewAppContext *a_app_context)
 {
         MlViewStyledView *view = NULL ;
@@ -849,8 +849,6 @@ mlview_styled_view_new (MlViewXMLDocument *a_doc,
                               NULL) ;
         view = g_object_new (MLVIEW_TYPE_STYLED_VIEW, NULL) ;
         mlview_styled_view_construct (view, a_doc, a_name, a_app_context) ;
-        mlview_iview_connect_to_doc (MLVIEW_IVIEW (view),
-                                     a_doc) ;
         return GTK_WIDGET (view) ;
 }
 
@@ -866,7 +864,7 @@ mlview_styled_view_new (MlViewXMLDocument *a_doc,
 enum MlViewStatus
 mlview_styled_view_construct (MlViewStyledView *a_this,
 			      MlViewXMLDocument *a_doc,
-			      guchar *a_view_name,
+			      const guchar *a_view_name,
 			      MlViewAppContext *a_app_context)
 {
         enum CRStatus cr_status = CR_OK ;
@@ -892,20 +890,20 @@ mlview_styled_view_construct (MlViewStyledView *a_this,
                 return MLVIEW_ERROR ;
         cascade = cr_cascade_new (NULL, NULL, sheet) ;
         if (!cascade) {
-                mlview_utils_trace_info ("cr_cascade_new() failed") ;
+                mlview_utils_trace_debug ("cr_cascade_new() failed") ;
                 status = MLVIEW_ERROR ;
                 goto cleanup ;
         }
         xml_doc = mlview_xml_document_get_xml_document (a_doc) ;
         if (!xml_doc) {
-                mlview_utils_trace_info 
+                mlview_utils_trace_debug 
                         ("mlview_xml_document_get_xml_document () failed") ;
                 status = MLVIEW_OK ;
                 goto cleanup ;
         }
         PRIVATE (a_this)->styled_editor = sx_box_view_new (cascade, xml_doc) ;
         if (!PRIVATE (a_this)->styled_editor) {
-                mlview_utils_trace_info ("sx_box_new() failed") ;
+                mlview_utils_trace_debug ("sx_box_new() failed") ;
                 status = MLVIEW_OK ;
                 goto cleanup ;
         }
@@ -928,6 +926,8 @@ mlview_styled_view_construct (MlViewStyledView *a_this,
         gtk_widget_show_all (GTK_WIDGET (PRIVATE (a_this)->main_paned)) ;
         PRIVATE (a_this)->app_context = a_app_context ;
 
+        mlview_iview_connect_to_doc (MLVIEW_IVIEW (view),
+                                     a_doc) ;
         g_signal_connect (G_OBJECT (PRIVATE (a_this)->styled_editor),
                           "button-press-event",
                           G_CALLBACK (button_press_event_cb),
