@@ -69,7 +69,7 @@ struct _MlViewTreeViewClass {
 GType mlview_tree_view_get_type (void);
 
 GtkWidget *mlview_tree_view_new (MlViewXMLDocument *a_doc,
-                                 gchar * a_name,
+                                 const gchar * a_name,
                                  MlViewAppContext *a_app_ctxt);
 
 void mlview_tree_view_set_app_context (MlViewTreeView * a_tree_view,
@@ -87,7 +87,7 @@ mlview_tree_view_get_trees (MlViewTreeView *a_this) ;
 
 void mlview_tree_view_construct (MlViewTreeView * a_tree_view,
                                  MlViewXMLDocument *a_doc,
-                                 gchar * a_name,
+                                 const gchar * a_name,
                                  MlViewAppContext *a_app_ctxt) ;
 
 enum MlViewStatus mlview_tree_view_create_internal_subset_node_interactive (MlViewTreeView *a_this) ;
