@@ -24,6 +24,7 @@
  *See COPYRIGHT file for copyright information.
  */
 #define ENABLE_NLS 1
+#define DBUS_API_SUBJECT_TO_CHANGE
 
 #include "config.h"
 #include <libgnome/libgnome.h>
@@ -43,56 +44,66 @@ G_BEGIN_DECLS
  *gtk and libxml2.
  */
         enum MlViewStatus {
-        MLVIEW_OK,
-        MLVIEW_BAD_PARAM_ERROR,
-        MLVIEW_NULL_FILE_NAME_ERROR,
-        MLVIEW_BAD_FILE_ERROR,
-        MLVIEW_EMPTY_FILE_ERROR,
-        MLVIEW_NO_SPACE_LEFT_ERROR,
-        MLVIEW_UNKNOWN_ENCODING_ERROR,
-        MLVIEW_ENCODING_ERROR,
-        MLVIEW_NO_ENCODINGS_ERROR,
-        MLVIEW_ENCODING_NOT_SUPPORTED_ERROR,
-        MLVIEW_CHAR_TOO_LONG_ERROR,
-        MLVIEW_OUT_OF_MEMORY_ERROR,
-        MLVIEW_NODE_NOT_FOUND_ERROR,
-        MLVIEW_OUT_OF_BOUNDS_ERROR,
-        MLVIEW_NO_LEFT_ANGLE_BRACKET_ERROR,
-        MLVIEW_NO_RIGHT_ANGLE_BRACKET_ERROR,
-        MLVIEW_NO_ROW_SELECTED_ERROR,
-        MLVIEW_PARSING_ERROR,
-        MLVIEW_BAD_URI_ERROR,
-        MLVIEW_INTERNAL_SUBSET_ALREADY_EXISTS_ERROR,
-        MLVIEW_ENTITY_NAME_EXISTS_ERROR,
-        MLVIEW_BAD_NODE_PARENT,
-        MLVIEW_EOF_ERROR,
-        MLVIEW_IFACE_NOT_DEFINED_ERROR,
-        MLVIEW_OBJECT_NOT_FOUND_ERROR,
-        MLVIEW_OBJECT_CONTAINER_NOT_EMPTY,
-        MLVIEW_PATH_TOO_DEEP_ERRROR,
-        MLVIEW_NO_DOC_IN_VIEW_ERROR,
-        MLVIEW_INT_SUBSET_ALREADY_PRESENT_ERROR,
-        MLVIEW_KEY_INPUTS_FULL_ERROR,
-        MLVIEW_KEY_BINDING_NOT_FOUND_ERROR,
-        MLVIEW_NOT_A_KEY_BINDING_ERROR,
-        MLVIEW_KEY_SEQUENCE_TOO_SHORT_ERROR,
-        MLVIEW_STACK_TOO_SHORT_ERROR,
-        MLVIEW_ENTRY_EMPTY_ERROR,
-        MLVIEW_STACK_EMPTY_ERROR,
-        MLVIEW_CANT_UNDO_ERROR,
-        MLVIEW_RESERVED_FOR_FUTURE_USE1_ERROR,
-        MLVIEW_RESERVED_FOR_FUTURE_USE2_ERROR,
-        MLVIEW_RESERVED_FOR_FUTURE_USE3_ERROR,
-        MLVIEW_RESERVED_FOR_FUTURE_USE4_ERROR,
-        MLVIEW_RESERVED_FOR_FUTURE_USE5_ERROR,
-        MLVIEW_RESERVED_FOR_FUTURE_USE6_ERROR,
-        MLVIEW_RESERVED_FOR_FUTURE_USE7_ERROR,
-        MLVIEW_RESERVED_FOR_FUTURE_USE8_ERROR,
-        MLVIEW_RESERVED_FOR_FUTURE_USE9_ERROR,
-        MLVIEW_RESERVED_FOR_FUTURE_USE10_ERROR,
-        MLVIEW_RESERVED_FOR_FUTURE_USE11_ERROR,
-        /*must be the last one */
-        MLVIEW_ERROR
+		MLVIEW_OK = 0,
+		MLVIEW_BAD_PARAM_ERROR,
+		MLVIEW_NULL_FILE_NAME_ERROR,
+		MLVIEW_BAD_FILE_ERROR,
+		MLVIEW_EMPTY_FILE_ERROR,
+		MLVIEW_NO_SPACE_LEFT_ERROR,
+		MLVIEW_UNKNOWN_ENCODING_ERROR,
+		MLVIEW_ENCODING_ERROR,
+		MLVIEW_NO_ENCODINGS_ERROR,
+		MLVIEW_ENCODING_NOT_SUPPORTED_ERROR,
+		MLVIEW_CHAR_TOO_LONG_ERROR,
+		MLVIEW_OUT_OF_MEMORY_ERROR,
+		MLVIEW_NODE_NOT_FOUND_ERROR,
+		MLVIEW_OUT_OF_BOUNDS_ERROR,
+		MLVIEW_NO_LEFT_ANGLE_BRACKET_ERROR,
+		MLVIEW_NO_RIGHT_ANGLE_BRACKET_ERROR,
+		MLVIEW_NO_ROW_SELECTED_ERROR,
+		MLVIEW_PARSING_ERROR,
+		MLVIEW_UNBALANCED_TAF_ERROR,
+		MLVIEW_NO_DANGLING_OPEN_TAG_FOUND_ERROR ,
+		MLVIEW_BAD_URI_ERROR,
+		MLVIEW_INTERNAL_SUBSET_ALREADY_EXISTS_ERROR,
+		MLVIEW_ENTITY_NAME_EXISTS_ERROR,
+		MLVIEW_BAD_NODE_PARENT,
+		MLVIEW_EOF_ERROR,
+		MLVIEW_IFACE_NOT_DEFINED_ERROR,
+		MLVIEW_OBJECT_NOT_FOUND_ERROR,
+		MLVIEW_OBJECT_CONTAINER_NOT_EMPTY_ERROR,
+		MLVIEW_PATH_TOO_DEEP_ERRROR,
+		MLVIEW_NO_DOC_IN_VIEW_ERROR,
+		MLVIEW_INT_SUBSET_ALREADY_PRESENT_ERROR,
+		MLVIEW_KEY_INPUTS_FULL_ERROR,
+		MLVIEW_KEY_BINDING_NOT_FOUND_ERROR,
+		MLVIEW_NOT_A_KEY_BINDING_ERROR,
+		MLVIEW_KEY_SEQUENCE_TOO_SHORT_ERROR,
+		MLVIEW_STACK_TOO_SHORT_ERROR,
+		MLVIEW_ENTRY_EMPTY_ERROR,
+		MLVIEW_STACK_EMPTY_ERROR,
+		MLVIEW_CANT_UNDO_ERROR,
+		MLVIEW_CANT_RELOAD_ERROR,
+		MLVIEW_NULL_POINTER_ERROR,
+		MLVIEW_NO_STAG_ERROR,
+		MLVIEW_SERVICE_START_ERROR,
+		MLVIEW_BUS_ERROR,
+		MLVIEW_CANNOT_START_SERVICE_ERROR,
+		MLVIEW_SERVICE_ALREADY_EXISTS_ERROR,
+		MLVIEW_PING_FAILED_ERROR,
+		MLVIEW_RESERVED_FOR_FUTURE_USE1_ERROR,
+		MLVIEW_RESERVED_FOR_FUTURE_USE2_ERROR,
+		MLVIEW_RESERVED_FOR_FUTURE_USE3_ERROR,
+		MLVIEW_RESERVED_FOR_FUTURE_USE4_ERROR,
+		MLVIEW_RESERVED_FOR_FUTURE_USE5_ERROR,
+		MLVIEW_RESERVED_FOR_FUTURE_USE6_ERROR,
+		MLVIEW_RESERVED_FOR_FUTURE_USE7_ERROR,
+		MLVIEW_RESERVED_FOR_FUTURE_USE8_ERROR,
+		MLVIEW_RESERVED_FOR_FUTURE_USE9_ERROR,
+		MLVIEW_RESERVED_FOR_FUTURE_USE10_ERROR,
+		MLVIEW_RESERVED_FOR_FUTURE_USE11_ERROR,
+		/*must be the last one */
+		MLVIEW_ERROR
 };
 
 enum MlViewEncoding {
@@ -110,29 +121,15 @@ struct NameValuePair {
  *Some miscellaneous macros definitions.
  */
 
-#  define MVLIEW_LOG_DOMAIN "MLVIEW"
+#define MLVIEW_LOG_DOMAIN "MLVIEW"
 
-#  ifdef __GNUC__
 
-#    define mlview_utils_trace(a_log_level, a_msg) \
-g_log (MVLIEW_LOG_DOMAIN, \
-       G_LOG_LEVEL_CRITICAL, \
-       "file %s: line %d (%s): %s\n", \
-       __FILE__, \
-       __LINE__, \
-       __PRETTY_FUNCTION__, \
-	a_msg)
-#  else
-      /*__GNUC__*/
-
-#    define mlview_utils_trace(a_log_level, a_msg) \
-g_log (MVLIEW_LOG_DOMAIN, \
-       G_LOG_LEVEL_CRITICAL, \
-       "file %s: line %d: %s\n", \
-       __FILE__, \
-       __LINE__, \
-       a_msg)
-#  endif
+#define mlview_utils_trace(a_log_level, ...) \
+g_log (MLVIEW_LOG_DOMAIN, a_log_level, "at %s:%d:",\
+       __FILE__,__LINE__) ;\
+g_log (MLVIEW_LOG_DOMAIN, \
+       a_log_level, \
+	__VA_ARGS__)
 
 /**
  *Traces an info message.
@@ -141,8 +138,8 @@ g_log (MVLIEW_LOG_DOMAIN, \
  *added to the message.
  *@param a_msg the msg to trace.
  */
-#  define mlview_utils_trace_info(a_msg) \
-mlview_utils_trace (G_LOG_LEVEL_INFO, a_msg)
+#  define mlview_utils_trace_info(...) \
+mlview_utils_trace (G_LOG_LEVEL_INFO, __VA_ARGS__)
 
 /**
  *Trace a debug message.
@@ -151,8 +148,12 @@ mlview_utils_trace (G_LOG_LEVEL_INFO, a_msg)
  *added to the message.
  *@param a_msg the msg to trace.
  */
-#  define mlview_utils_trace_debug(a_msg) \
-mlview_utils_trace (G_LOG_LEVEL_DEBUG, a_msg) ;
+#ifdef MLVIEW_DEBUG
+#define mlview_utils_trace_debug(...) \
+mlview_utils_trace (G_LOG_LEVEL_DEBUG, __VA_ARGS__) 
+#else
+#define mlview_utils_trace_debug(...) 
+#endif
 
 int mlview_utils_load_xml_document (gchar * a_xmlfile,
                                     xmlParserCtxtPtr
@@ -177,41 +178,77 @@ gboolean mlview_utils_is_combining (gint a_c) ;
 gboolean mlview_utils_is_extender (gint a_c) ;
 
 gboolean mlview_utils_is_ideographic (gint a_c) ;
+
 gboolean mlview_utils_is_letter (gint a_c) ;
+
 gboolean mlview_utils_is_name_char (gint a_c) ;
+
 gboolean mlview_utils_is_digit (gint a_c) ;
+
 gboolean mlview_utils_is_space (gint a_c) ;
+
 gboolean mlview_utils_is_pubidchar (gint a_c) ;
+
 enum MlViewStatus mlview_utils_skip_spaces (guchar *a_raw_str,
                                             guchar **a_skiped_to) ;
+
+enum MlViewStatus mlview_utils_skip_spaces2 (GtkTextIter *a_raw_str,
+                                             GtkTextIter **a_skiped_to) ;
+
 enum MlViewStatus mlview_utils_parse_element_name (guchar *row_str,
                                                    guchar **a_name_end) ;
+
+enum MlViewStatus mlview_utils_parse_element_name2 (GtkTextIter *a_from,
+                                                    GtkTextIter **a_name_start,
+						    GtkTextIter **a_name_end) ;
+
 enum MlViewStatus mlview_utils_parse_reference (guchar *a_raw_str,
                                                 guchar **a_ref_end) ;
+
+enum MlViewStatus mlview_utils_parse_reference2 (GtkTextIter *a_from,
+					         GtkTextIter **a_ref_end) ;
+
 enum MlViewStatus mlview_utils_parse_attribute (guchar *a_raw_str,
                                                 guchar **a_name_end,
                                                 guchar **a_val_start,
                                                 guchar **a_val_end)  ;
+
+enum MlViewStatus mlview_utils_parse_attribute2 (GtkTextIter *a_from,
+					         GtkTextIter **a_name_end,
+					         GtkTextIter **a_val_start,
+					         GtkTextIter **a_val_end) ;
+
 enum MlViewStatus mlview_utils_parse_comment (guchar *a_raw_str,
                                               GString **a_comment) ;
+
 enum MlViewStatus mlview_utils_parse_pi (guchar *a_raw_pi,
                                          GString **a_pi_target,
                                          GString **a_pi_param) ;
+
 enum MlViewStatus mlview_utils_parse_start_tag (guchar *a_raw_str,
                                                 GString **a_name,
                                                 GList **a_name_value_pair_list) ;
 
+enum MlViewStatus mlview_utils_parse_start_tag2 (GtkTextIter *a_from,
+					         GString **a_name,
+					         GList **a_name_value_pair_list,
+						 GtkTextIter **a_to,
+						 gboolean *a_is_empty_tag) ;
+
+enum MlViewStatus mlview_utils_parse_closing_tag2 (GtkTextIter *a_from,
+						   GString **a_name) ;
+
 enum MlViewStatus mlview_utils_parse_cdata_section (const gchar *a_raw_str,
                                                     gchar **a_out_start,
                                                     gchar **a_out_end) ;
-enum MlViewStatus
-mlview_utils_parse_doctype_decl (guchar *a_instr,
-                                 guchar **a_name_start,
-                                 guchar **a_name_end,
-                                 guchar **a_public_id_start,
-                                 guchar **a_public_id_end,
-                                 guchar **a_external_id_start,
-                                 guchar **a_external_id_end) ;
+
+enum MlViewStatus mlview_utils_parse_doctype_decl (guchar *a_instr,
+						   guchar **a_name_start,
+						   guchar **a_name_end,
+						   guchar **a_public_id_start,
+						   guchar **a_public_id_end,
+						   guchar **a_external_id_start,
+						   guchar **a_external_id_end) ;
 
 enum MlViewStatus
 mlview_utils_parse_external_id (guchar *a_instr,
@@ -359,6 +396,10 @@ enum MlViewStatus mlview_utils_relative_uri_to_absolute_uri (const gchar *a_rela
                                                              const gchar* a_base_uri,
                                                              gchar **a_absolute_uri) ;
 
+void
+xmlDictFreeMem (xmlDict *a_dict,
+                xmlChar* a_mem) ;
+
 xmlNs *xmlUnlinkNs (xmlNode * node, xmlNs * ns);
 
 xmlNs *xmlUnlinkNsDef (xmlNode * node, xmlNs * ns);
@@ -420,6 +461,33 @@ gchar *mlview_utils_get_unique_string (const gchar *a_prefix) ;
 
 gchar * mlview_utils_escape_underscore_for_gtk_widgets (const gchar *a_in_string) ;
 
+gchar * mlview_utils_replace_word (const gchar *a_input_string,
+				   const gchar *a_lookup_word,
+				   const gchar *a_replacement_word) ;
+
+const gchar * mlview_utils_combo_box_get_active_text (GtkComboBox *combo_box) ;
+
+GList * mlview_utils_push_on_stack (GList *a_stack, gpointer a_element) ;
+
+GList * mlview_utils_pop_from_stack (GList *a_stack, gpointer *a_element) ;
+
+GList *mlview_utils_peek_from_stack (GList *a_stack, gpointer *a_element) ;
+
+GtkTextIter * mlview_utils_text_iter_forward_chars_dup (GtkTextIter *a_iter,
+		                                        guint a_count) ;
+
+enum MlViewStatus mlview_utils_text_iter_get_char_at (GtkTextIter *a_iter,
+		                                      guint a_count,
+						      gunichar *a_char) ;
+
+enum MlViewStatus mlview_utils_text_iter_get_iter_at (GtkTextIter *a_cur_iter,
+		                                      guint a_count,
+						      GtkTextIter **a_iter) ;
+
+enum MlViewStatus mlview_utils_lookup_action_group (GtkUIManager *a_manager,
+		                                    const gchar * a_name,
+		                                    GtkActionGroup **a_action_group) ;
+
 G_END_DECLS
 
 #endif
