@@ -35,6 +35,7 @@ struct _MlViewValidatorWindow {
         GtkWidget *validation_report;
         GtkWidget *document_label;
         GtkWidget *status_label;
+	GtkWidget *status_icon;
 
         struct {
                 GtkWidget *view;
@@ -139,9 +140,12 @@ document_changed_cb (MlViewValidatorWindow *a_window)
 {
         g_return_if_fail (a_window);
         g_return_if_fail (a_window->status_label);
+	g_return_if_fail (a_window->status_icon);
 
         gtk_label_set_text (GTK_LABEL (a_window->status_label),
-                            _("Document changed ; press 'Refresh'"));
+                            _("Document changed; Re-run validation"));
+	gtk_widget_set_sensitive (GTK_WIDGET (a_window->status_icon), FALSE);
+
 }
 
 static void
@@ -279,7 +283,7 @@ validate_button_clicked_cb (GtkWidget *a_button,
                 *label = NULL;
         MlViewSchema *schema = NULL;
         MlViewValidatorStatus status = VALIDATOR_ERROR;
-        gint i = 0;
+        guint i = 0;
         MlViewValidationMessage *message = NULL;
         MlViewAppContext *ctxt = NULL;
         GdkPixbuf *pix = NULL;
@@ -292,6 +296,7 @@ validate_button_clicked_cb (GtkWidget *a_button,
         g_return_if_fail (a_window->output.view);
         g_return_if_fail (a_window->validation_report);
         g_return_if_fail (a_window->status_label);
+	g_return_if_fail (a_window->status_icon);
         
         res = gtk_combo_box_get_active_iter 
                 (GTK_COMBO_BOX (a_window->schemas.combo), &iter);
@@ -353,14 +358,20 @@ validate_button_clicked_cb (GtkWidget *a_button,
         case VALIDATOR_ERROR:
                 gtk_label_set_text (GTK_LABEL (a_window->status_label),
                                     _("Validation error"));
+		gtk_image_set_from_stock (GTK_IMAGE (a_window->status_icon), GTK_STOCK_STOP, GTK_ICON_SIZE_SMALL_TOOLBAR);
+		gtk_widget_set_sensitive (GTK_WIDGET (a_window->status_icon), TRUE);
                 break;
         case VALIDATOR_VALID_DOC:
                 gtk_label_set_text (GTK_LABEL (a_window->status_label),
                                     _("Valid document"));
+		gtk_image_set_from_stock (GTK_IMAGE (a_window->status_icon), GTK_STOCK_YES, GTK_ICON_SIZE_SMALL_TOOLBAR);
+		gtk_widget_set_sensitive (GTK_WIDGET (a_window->status_icon), TRUE);
                 break;
         case VALIDATOR_INVALID_DOC:
                 gtk_label_set_text (GTK_LABEL (a_window->status_label),
                                     _("Invalid document"));
+		gtk_image_set_from_stock (GTK_IMAGE (a_window->status_icon), GTK_STOCK_NO, GTK_ICON_SIZE_SMALL_TOOLBAR);
+		gtk_widget_set_sensitive (GTK_WIDGET (a_window->status_icon), TRUE);
                 break;
         }
         
@@ -378,7 +389,7 @@ validate_button_clicked_cb (GtkWidget *a_button,
                         g_object_unref (G_OBJECT (a_window->output.store));
                         a_window->output.store = NULL;
                         
-                        mlview_utils_trace_info ("validate_button_clicked_cb failed.");
+                        mlview_utils_trace_debug ("validate_button_clicked_cb failed.");
 
                         return;
                 }
@@ -449,7 +460,7 @@ validate_button_clicked_cb (GtkWidget *a_button,
                 dialog = NULL;
         }
 
-        mlview_utils_trace_info ("validate_button_clicked_cb failed.");
+        mlview_utils_trace_debug ("validate_button_clicked_cb failed.");
 }
 
 static void
@@ -591,6 +602,11 @@ mlview_validator_window_new (MlViewXMLDocument *a_doc)
         if (!(win->status_label && GTK_IS_LABEL (win->status_label)))
                 goto cleanup;
 
+	win->status_icon = glade_xml_get_widget (xml, "StatusIcon");
+
+	if (!(win->status_icon && GTK_IS_IMAGE (win->status_icon)))
+		goto cleanup;
+
         /* Output view */ 
 
         win->output.view = glade_xml_get_widget (xml, "OutputView");
