@@ -217,6 +217,15 @@ struct _MlViewXMLDocumentClass {
 
         void (*document_closed) (MlViewXMLDocument *a_this,
                                  gpointer a_user_data);
+
+        void (*document_reloaded) (MlViewXMLDocument *a_this,
+                                   gpointer a_user_data);
+
+	void (*going_to_save) (MlViewXMLDocument *a_this,
+			       gpointer a_user_data) ;
+
+	void (*document_undo_state_changed) (MlViewXMLDocument *a_this,
+	                                     gpointer a_user_data) ;
 };
 
 guint mlview_xml_document_get_type (void);
@@ -230,25 +239,27 @@ void mlview_xml_document_ref (MlViewXMLDocument * a_this);
 
 void mlview_xml_document_unref (MlViewXMLDocument * a_this);
 
-MlViewXMLDocument *mlview_xml_document_open_with_dtd_interactive (gchar * a_file_name,
-                                                                  MlViewAppContext *a_context);
+MlViewXMLDocument *mlview_xml_document_open_with_dtd_interactive 
+						(const gchar * a_file_name,
+					         MlViewAppContext *a_context);
 
 xmlNode * mlview_xml_document_get_node_from_clipboard2 (xmlDoc * a_xml_doc) ;
 
 MlViewXMLDocument * mlview_xml_document_clone (MlViewXMLDocument *a_original);
 
-MlViewFileDescriptor * mlview_xml_document_get_file_descriptor (MlViewXMLDocument * a_xml_doc);
+MlViewFileDescriptor * mlview_xml_document_get_file_descriptor 
+							(MlViewXMLDocument * a_xml_doc);
 
 void mlview_xml_document_set_file_descriptor (MlViewXMLDocument * a_xml_doc,
                                               MlViewFileDescriptor * a_file_desc);
 
 void mlview_xml_document_set_file_path (MlViewXMLDocument * a_xml_doc,
-                                        gchar * a_file_path);
+                                        const gchar * a_file_path);
 gchar *mlview_xml_document_get_file_path (MlViewXMLDocument * a_xml_doc);
 
 MlViewAppContext * mlview_xml_document_get_app_context (MlViewXMLDocument * a_doc);
 
-xmlDocPtr mlview_xml_document_get_xml_document (MlViewXMLDocument * a_xml_doc);
+xmlDocPtr mlview_xml_document_get_native_document (MlViewXMLDocument * a_xml_doc);
 
 void mlview_xml_document_set_app_context (MlViewXMLDocument * a_doc,
                                           MlViewAppContext * a_context);
@@ -262,6 +273,17 @@ gint mlview_xml_document_save (MlViewXMLDocument *a_doc,
                                gboolean a_check_overwrt);
 
 
+gint mlview_xml_document_save_xml_doc (MlViewXMLDocument * a_xml_doc,
+                                       gchar * a_file_path)  ;
+
+void mlview_xml_document_save_xml_doc2 (MlViewXMLDocument *a_xml_doc,
+		                        gchar **a_buffer,
+				        gint *a_buffer_len) ;
+
+enum MlViewStatus mlview_xml_document_reload_from_buffer (MlViewXMLDocument *a_this,
+		                                          const gchar *a_buffer,
+					                  gboolean a_emit_signal) ;
+
 /**************************************
  *Document Edition interfaces.
  ***************************************/
@@ -334,6 +356,8 @@ enum MlViewStatus mlview_xml_document_node_get_name (xmlNode * a_node,
                                                      enum MlViewEncoding a_enc, 
                                                      guchar ** a_outbuf);
 
+const gchar * mlview_xml_document_get_mime_type (MlViewXMLDocument *a_this) ;
+
 enum MlViewStatus mlview_xml_document_set_attribute (MlViewXMLDocument *a_this,
                                                      const gchar *a_node_path,
                                                      const xmlChar* a_name,
@@ -444,8 +468,8 @@ MlViewSchemaList *mlview_xml_document_get_schema_list (MlViewXMLDocument *a_doc)
 gboolean mlview_xml_document_set_ext_subset_with_url (MlViewXMLDocument *a_doc,
                                                       const gchar *a_url);
 
-MlViewXMLDocument *mlview_xml_document_open_with_dtd (gchar * a_file_name,
-                                                      gchar * a_dtd_name,
+MlViewXMLDocument *mlview_xml_document_open_with_dtd (const gchar * a_file_name,
+                                                      const gchar * a_dtd_name,
                                                       MlViewAppContext * a_context);
 
 
@@ -484,5 +508,11 @@ enum MlViewStatus mlview_xml_document_get_node_path (MlViewXMLDocument *a_this,
 enum MlViewStatus mlview_xml_document_get_root_element (MlViewXMLDocument *a_this,
                                                         xmlNode **a_root_element) ;
 
+gboolean mlview_xml_document_is_standalone (MlViewXMLDocument *a_this);
+
+void mlview_xml_document_set_standalone (MlViewXMLDocument *a_this, gboolean standalone);
+
+enum MlViewStatus mlview_xml_document_notify_undo_state_changed 
+						(MlViewXMLDocument *a_this) ;
 G_END_DECLS
 #endif
